@@ -997,6 +997,18 @@ class TableClientSettings(object):
         self._native_date_in_result_sets = False
         self._make_result_sets_lazy = False
         self._native_json_in_result_sets = False
+        self._native_interval_in_result_sets = False
+        self._native_timestamp_in_result_sets = False
+
+    def with_native_timestamp_in_result_sets(self, enabled):
+        # type:(bool) -> ydb.TableClientSettings
+        self._native_timestamp_in_result_sets = enabled
+        return self
+
+    def with_native_interval_in_result_sets(self, enabled):
+        # type:(bool) -> ydb.TableClientSettings
+        self._native_interval_in_result_sets = enabled
+        return self
 
     def with_native_json_in_result_sets(self, enabled):
         # type:(bool) -> ydb.TableClientSettings
@@ -1027,11 +1039,29 @@ class TableClientSettings(object):
 class ScanQueryResult(object):
     def __init__(self, result, table_client_settings):
         self._result = result
+        self.query_stats = result.query_stats
         self.result_set = convert.ResultSet.from_message(
             self._result.result_set, table_client_settings
         )
 
 
+@enum.unique
+class QueryStatsCollectionMode(enum.IntEnum):
+    NONE = _apis.ydb_table.QueryStatsCollection.Mode.STATS_COLLECTION_NONE
+    BASIC = _apis.ydb_table.QueryStatsCollection.Mode.STATS_COLLECTION_BASIC
+    FULL = _apis.ydb_table.QueryStatsCollection.Mode.STATS_COLLECTION_FULL
+
+
+class ScanQuerySettings(settings_impl.BaseRequestSettings):
+    def __init__(self):
+        super(ScanQuerySettings, self).__init__()
+        self.collect_stats = None
+
+    def with_collect_stats(self, collect_stats_mode):
+        self.collect_stats = collect_stats_mode
+        return self
+
+
 class ScanQuery(object):
     def __init__(self, yql_text, parameters_types):
         self.yql_text = yql_text
@@ -1047,10 +1077,16 @@ def _scan_query_request_factory(query, parameters=None, settings=None):
     if not isinstance(query, ScanQuery):
         query = ScanQuery(query, {})
     parameters = {} if parameters is None else parameters
+    collect_stats = getattr(
+        settings,
+        "collect_stats",
+        _apis.ydb_table.QueryStatsCollection.Mode.STATS_COLLECTION_NONE,
+    )
     return _apis.ydb_table.ExecuteScanQueryRequest(
         mode=_apis.ydb_table.ExecuteScanQueryRequest.Mode.MODE_EXEC,
         query=_apis.ydb_table.Query(yql_text=query.yql_text),
         parameters=convert.parameters_to_pb(query.parameters_types, parameters),
+        collect_stats=collect_stats,
     )
 
 
